#!/usr/bin/env python
import os
import sys
import time
import getopt
import socket
import string
import commands
import subprocess
import threading
from multiprocessing import Process


# Golbal variables definition
TOOL_NAME = "CwS Harvest Location Permission Checker"
DEBUG = False
RULE = "rwxrwsrwx"
SUCCESS = True
resource_group = []
Get_Host_List_Method = True
WRITE_LOG = False
file_name=''

def isNotBlank(myString):
    if myString and myString.strip():
        #myString is not None AND myString is not empty or blank
        return True
    #myString is None OR myString is empty or blank
    return False

def create_output(msg):
	global file_name
	#print "file_name = %s" %file_name
	if isNotBlank(msg):
		report_file = open(file_name,'a')
		if not report_file:
			print "open file failed."
    	report_file.write(msg)
    	report_file.write("\n")
    	report_file.flush()
    	# Close report file
    	report_file.close()

# Check CwS Environment and get $EGO_CONFDIR
def check_env():
	global SUCCESS
	global EGO_CONFDIR
	global WRITE_LOG
	command_string = "env | grep EGO_CONFDIR"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: check_env()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" %(command_string, result) + "-" * 20
		print msg
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: Environment not set. Please source environment and run again." % command_string
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
		sys.exit()
	else:
		if not result[1]:
			msg = "Error: Environment not set. Please source environment and run again. Exit..."
			print msg
			if WRITE_LOG:
				create_output(msg)
			SUCCESS = False
			sys.exit()
		else:
			EGO_CONFDIR = result[1].split("=")[1]

			if DEBUG:
				msg = "DEBUG: The user has already sourced the environment. EGO_CONFDIR = %r" % EGO_CONFDIR
				print msg
				if WRITE_LOG:
					create_output(msg)

# Get Cluster Administrator
def get_cluster_admin():
	global SUCCESS
	global WRITE_LOG
	command_string = "cat $EGO_CONFDIR/ego.cluster.* | grep Administrators"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: get_cluster_admin()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
		sys.exit()
	else:
		if not result[1]:
			msg = "Error: Get cluster admin failed. Please check your cluster configurations. Exit..."
			print msg
			if WRITE_LOG:
				create_output(msg)
			SUCCESS = False
			sys.exit()
		else:

			try:
				cluster_amdin = result[1].split("=")[1].strip()

				if DEBUG:
					msg = "DEBUG: CLUSTER_ADMIN = %r" % cluster_amdin
					print msg
					if WRITE_LOG:
						create_output(msg)
				return cluster_amdin
			except:
				msg = "Get cluster admin failed, open debug message for function get_cluster_admin()."
				print msg
				if WRITE_LOG:
					create_output(msg)
				sys.exit()

# Get Cluster Administrator Group
def get_admin_group(cluster_admin):
	global SUCCESS
	global WRITE_LOG
	command_string = "id " + cluster_admin + " -g -n"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: get_admin_group()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
		sys.exit()
	else:
		if not result[1]:
			msg = "Error: Get cluster admin group failed. not result"
			print msg
			if WRITE_LOG:
				create_output(msg)
			SUCCESS = False
			sys.exit()
		else:
			admin_group = result[1]

			if DEBUG:
				msg = "DEBUG: ADMIN_GROUP = %r" % admin_group
				print msg
				if WRITE_LOG:
					create_output(msg)

			return admin_group

# Get host list
def get_host_list1():
	global SUCCESS
	global WRITE_LOG
	command_string = "egosh resource list -ll"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: get_host_list()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
		sys.exit()
	else:
		if not result[1]:
			msg = "Error: Get host list failed. No result."
			print msg
			if WRITE_LOG:
				create_output(msg)
			SUCCESS = False
			sys.exit()
		else:
			try:
				host_list = []
				i = 0
				lines = result[1].split('\n')
				for line in lines:
					if i == 0:
						i += 1
						continue

					host_list.append(line.split(',')[0].strip('"'))
					i += 1

				return host_list

			except Exception as e:
				msg = "Error: Get host list failed."
				print msg
				if WRITE_LOG:
					create_output(msg)
				SUCCESS = False
				raise e

def getResourceGroup(rg_type):
	global resource_group
	global WRITE_LOG
	command_string = "grep -A 2 " + rg_type + ": " + EGO_CONFDIR + "/../../ascd/work/appinstances/* | grep value"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: getResourceGroup()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		# print "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		# SUCCESS = False
		# sys.exit()
		msg = "WARNING: Doesn't find any resource group for type % r" %rg_type
		print msg
		if WRITE_LOG:
			create_output(msg)
	else:
		if not result[1]:
			msg = "Warning: No %s resource group in SIG configuration files" %rg_type
			print msg
			if WRITE_LOG:
				create_output(msg)
		else:
			try:
				lines = result[1].split('\n')
				for line in lines:
					rg = line.split(':')[1].strip(' ') 
					if DEBUG:
						msg = "type = %r, rg = %r, resource_group = %r" %(rg_type, rg, resource_group)
						print msg
						if WRITE_LOG:
							create_output(msg)
					if rg not in resource_group:
						resource_group.append(rg)
				pass
			except Exception as e:
				msg = "Error: Parse SIG yaml files failed."
				print msg
				if WRITE_LOG:
					create_output(msg)
				SUCCESS = False
				return

def get_host_list2():
	global resource_group
	global WRITE_LOG
	getResourceGroup("sparkms_batch_rg_param")
	getResourceGroup("driver_rg_param")
	getResourceGroup("executor_rg_param")
	getResourceGroup("executor_gpu_rg_param")
	
	if DEBUG:
		msg = "DEBUG: Final resource group = %r" %resource_group
		print msg
		if WRITE_LOG:
			create_output(msg)

	host_list = []
	for rg in resource_group:
		command_string = "egosh rg " + rg + " | grep 'Resource List'"
		result = commands.getstatusoutput(command_string)

		if DEBUG:
			msg = "\nDEBUG: get_host_list2()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
			print msg
			if WRITE_LOG:
				create_output(msg)

		if result[0] != 0:
			msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
			print msg
			if WRITE_LOG:
				create_output(msg)
			SUCCESS = False
			sys.exit()
		else:
			if not result[1]:
				msg = "Error: Get host list failed. No result."
				print msg
				if WRITE_LOG:
					create_output(msg)
				SUCCESS = False
				sys.exit()
			else:
				try:
					resource_list = result[1].split(':')[1].strip(' ').split(' ')
					for host in resource_list:
						if host not in host_list:
							host_list.append(host)
						pass
				except Exception as e:
					msg = "Error: Get host list failed."
					print msg
					if WRITE_LOG:
						create_output(msg)
					SUCCESS = False
					raise e
	if DEBUG:
		msg = "DEBUG: Final host_list = %r" %host_list
		print msg
		if WRITE_LOG:
			create_output(msg)
	return host_list

# Get ELK_HARVEST_LOCATION from $EGO_CONFDIR/../../eservice/esc/conf/services/elk_shipper.xml
def get_harvest_location():
	global SUCCESS
	global WRITE_LOG
	command_string = "cat "+ EGO_CONFDIR + "/../../eservice/esc/conf/services/elk_shipper.xml | grep ELK_HARVEST_LOCATION"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: get_harvest_location()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
		sys.exit()
	else:
		if not result[1]:
			msg = "Warning: No ELK_HARVEST_LOCATION parameter is defined in $EGO_CONFDIR/../../eservice/esc/conf/services/elk_shipper.xml. Will use default value: /var/tmp/elk_logs."
			print msg
			if WRITE_LOG:
				create_output(msg)
			return "/var/tmp/elk_logs"
		else:
			location = result[1].split('>')[1].split('<')[0]
			return location

# Check if installed on shared directory
def shared_fs():
	global SUCCESS
	global WRITE_LOG
	command_string = "cat "+ EGO_CONFDIR + "/../../ascd/conf/ascd.conf | grep ASCD_SHARED_FS_DEPLOY"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: shared_fs()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
		sys.exit()
	else:
		if not result[1]:
			msg = "The cluster is installed on local directory."
			print msg
			if WRITE_LOG:
				create_output(msg)
			return False
		else:
			ASCD_SHARED_FS_DEPLOY = result[1].split('=')[1]
			if ASCD_SHARED_FS_DEPLOY == "ON":
				msg = "The cluster is installed on shared directory."
				print msg
				if WRITE_LOG:
					create_output(msg)
				return True
			else:
				msg = "The cluster is installed on local directory."
				print msg
				if WRITE_LOG:
					create_output(msg)
				return False

# Check if the directory exists
def dir_exist(path):
	return os.path.isdir(path) and os.path.exists(path)

# Check if there's enough space
def check_avail_space(dir, DD_FILE_SIZE, hostname):
    global WRITE_LOG
    stat_cmd = "echo $(($(stat -f --format=\"%%a*%%s\" %s)))" % dir
    command_string = "ssh " + hostname + " \"" + stat_cmd + "\""
    result = commands.getstatusoutput(command_string)
    if DEBUG:
		msg = "DEBUG: check_avail_space()\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		print ""
		if WRITE_LOG:
			create_output(msg)

    if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		return -1
    else:
	    if not result[1]:
	        msg = "Error: Check disk space failed on %s. Exit..." % dir
	        print msg
	        if WRITE_LOG:
	        	create_output(msg)
	        return -1
	    else:
	        free_mb = int(result[1]) / (1024 * 1024)
	        #print "free_mb: %d, DD_FILE_SIZE: %d" % (free_mb, DD_FILE_SIZE)
	        if free_mb > DD_FILE_SIZE:
	            #print "Enough space"
	            return 0
	        else:
	            msg = "Error: NOT Enough space, your directory only has %s MB" % free_mb
	            print msg
	            if WRITE_LOG:
					create_output(msg)
	            return free_mb

# Run dd
def run_command_with_timeout(cmd, timeout_sec):
    proc = subprocess.Popen(cmd, shell=True)
    proc_thread = threading.Thread(target=proc.communicate)
    proc_thread.start()
    proc_thread.join(timeout_sec)
    if proc_thread.is_alive():
        try:
            proc.kill()
        except OSErrot, e:
            return proc.returncode
    #print "proc.returncode: %d" % proc.returncode
    return proc.returncode

def run_dd_test(dd_cmd, DD_FILE_SIZE, DD_BLOCK_SIZE, dir_value, DD_CMD_TIMEOUT):
    global WRITE_LOG
	# print progress
    progress_p = Process(target=print_progress, args=("p1", 1))
    progress_p.start()

    return_code = run_command_with_timeout(dd_cmd, DD_CMD_TIMEOUT)

    # stop progress bar
    progress_p.terminate()

    if DEBUG:
    	msg = "dd return code: " + str(return_code)
    	print msg
    	if WRITE_LOG:
			create_output(msg)

    return return_code

def print_progress(procName, delay):
    global WRITE_LOG
    while (1):
        time.sleep(delay)
        sys.stdout.write(".")
        sys.stdout.flush()

# Check I/O
def check_IO(path, hostname):
	global WRITE_LOG
	DD_FILE_SIZE = 50 #MB
	DD_BLOCK_SIZE = 1024 #Byte
	DD_CMD_TIMEOUT = 10 #sec
	DD_COUNT = (DD_FILE_SIZE * 1024 * 1024) // DD_BLOCK_SIZE #"//" means floor division
	dd_cmd = "dd if=/dev/zero of=%s/dd_out.img bs=%d count=%d conv=fsync" % (path, DD_BLOCK_SIZE, DD_COUNT)
	command_string = "ssh " + hostname + " '" + dd_cmd + "'"

	# Check enough space
	msg = "Check available disk space ..."
	print msg
	if WRITE_LOG:
		create_output(msg)
	space_result = check_avail_space(path, DD_FILE_SIZE, hostname)
	if space_result != 0:
		msg = ">>> Wrong!"
		print msg
		if WRITE_LOG:
			create_output(msg)
		return -1
	else:
		msg = ">>> Ok!"
		print msg
		if WRITE_LOG:
			create_output(msg)

	# Write a file
	msg = "Run dd command to check write performance ..."
	print msg
	if WRITE_LOG:
		create_output(msg)
	dd_result = run_dd_test(command_string, DD_FILE_SIZE, DD_BLOCK_SIZE, path, DD_CMD_TIMEOUT)
	if dd_result != 0:
		msg = "Error : Testing dd command failed!"
		print msg
		if WRITE_LOG:
			create_output(msg)
		msg = ">>> Wrong!"
		print msg
		if WRITE_LOG:
			create_output(msg)
		return -2
	else:
		msg = ">>> OK!"
		print msg
		if WRITE_LOG:
			create_output(msg)

	# Check if the file readable
	msg = "Check if the file is readable ..."
	print msg
	if WRITE_LOG:
		create_output(msg)
	stat_cmd = "ssh " + hostname + " 'stat -c %%a %s/dd_out.img'" % path
	stat_result = commands.getstatusoutput(stat_cmd)
	if stat_result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (stat_cmd, stat_result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		return -3
	else:
		#print stat_result[1]
		stat_value = int(stat_result[1])
		if stat_value < 444:
			msg = "Error: The file doesn't have enough read permission %r." % stat_value
			print msg
			if WRITE_LOG:
				create_output(msg)
			msg = ">>> Wrong!"
			print msg
			if WRITE_LOG:
				create_output(msg)
			return -3
		else:
			msg = ">>> OK!"
			print msg
			if WRITE_LOG:
				create_output(msg)

	# Check the file's group
	msg = "Check the file's group ..."
	print msg
	if WRITE_LOG:
		create_output(msg)
	ls_command = "ssh " + hostname + " 'ls -l %s/dd_out.img'" % path
	ls_result = commands.getstatusoutput(ls_command)
	if ls_result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (ls_command, ls_result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		return -4
	else:
		permission = ls_result[1]
		permission_list = permission.split(' ')
		if permission_list[3] != ADMIN_GROUP:
			msg = "Error: The group of the file is %r, which is incorrect!" % permission_list[3]
			print msg
			if WRITE_LOG:
				create_output(msg)
			msg = ">>> Wrong!"
			print msg
			if WRITE_LOG:
				create_output(msg)
			return -4
		else:
			msg = ">>> OK!"
			print msg
			if WRITE_LOG:
				create_output(msg)

	# Delete the testing file.
	del_command = "ssh " + hostname + " 'rm -f %s/dd_out.img'" % path
	del_result = commands.getstatusoutput(del_command)
	if del_result[0] != 0:
		msg = "Error: Delete %s/dd_out.img on host %s failed." % (path, hostname)
		print msg
		if WRITE_LOG:
			create_output(msg)

	return 0

# Check permission
def check_permission(hostname):
	global WRITE_LOG
	global SUCCESS
	msg = "\nCheck permission on host: %s." % hostname
	print msg
	if WRITE_LOG:
		create_output(msg)
	msg = "=" * 40
	print msg
	if WRITE_LOG:
		create_output(msg)
	# 1. Get directory path according to SHARE_FS
	path = ""
	if SHARE_FS:
		command_string = "ssh " + hostname + " 'ls -l " + ELK_HARVEST_LOCATION + "'"
		result = commands.getstatusoutput(command_string)

		if DEBUG:
			msg = "DEBUG: check_permission() -> SHARE_FS = True\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
			print msg
			print ""
			if WRITE_LOG:
				create_output(msg)

		if result[0] != 0:
			msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
			print msg
			if WRITE_LOG:
				create_output(msg)
			SUCCESS = False
			return
		else:
			try:
				path = result[1].split('>')[1].strip()
				if path == ELK_HARVEST_LOCATION:
					msg = "Error: You doesn't set a replacement ELK log directory for host %s. Please check your configuration." % hostname
					print msg
					if WRITE_LOG:
						create_output(msg)
					SUCCESS = False
					return
			except Exception as e:
				msg = "Error: You doesn't set a replacement ELK log directory for host %s. Please check your configuration." % hostname
				print msg
				if WRITE_LOG:
					create_output(msg)
				SUCCESS = False
				return
	else:
		path = ELK_HARVEST_LOCATION

	msg = hostname + "'s ELK log directory is " + path
	print msg
	if WRITE_LOG:
		create_output(msg)

	# 2. Get the permission of path
	permission = ""
	command_string = "ssh " + hostname + " 'ls -ld " + path + "'"
	result = commands.getstatusoutput(command_string)

	if DEBUG:
		msg = "\nDEBUG: check_permission() -> SHARE_FS = True\n" + "-" * 20 + "\ncommand: %r \nresult: %r \n" % (command_string, result) + "-" * 20
		print msg
		print ""
		if WRITE_LOG:
			create_output(msg)

	if result[0] != 0:
		msg = "Error: Command %r failed. Exit... \nDetails: %s." % (command_string, result[1])
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
		return
	else:
		permission = result[1]

	permission_list = permission.split(' ')

	# 3. Compare the permission with RULE
	if RULE not in permission_list[0]:
		msg = "Error: The permission of the directpry is %r, which is incorrect! Please change permission to %r." % (permission_list[0], RULE)
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
	else:
		msg = "The permission of the directory is %r, which is correct." % permission_list[0]
		print msg
		if WRITE_LOG:
			create_output(msg)

	if permission_list[2] != CLUSTER_ADMIN:
		msg = "Error: The owner of the directory is %r, which is incorrect! Please change owner to %r." % (permission_list[2], CLUSTER_ADMIN)
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
	else:
		msg = "The owner of the directory is %r, which is correct." % permission_list[2]
		print msg
		if WRITE_LOG:
			create_output(msg)

	if permission_list[3] != ADMIN_GROUP:
		msg = "Error: The group of the directory is %r, which is incorrect! Please change the group to %r." % (permission_list[3], ADMIN_GROUP)
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
	else:
		msg = "The group of the directory is %r, which is correct." % permission_list[3]
		print msg
		if WRITE_LOG:
			create_output(msg)

	msg = "\nStart I/O checking:"
	print msg
	if WRITE_LOG:
		create_output(msg)
	io_result = check_IO(path, hostname)
	if io_result != 0:
		msg = "Error: Writing or Reading on this directory has problems."
		print msg
		if WRITE_LOG:
			create_output(msg)
		SUCCESS = False
	else:
		msg = "I/O Checking passed."
		print msg
		if WRITE_LOG:
			create_output(msg)

	msg = "=" * 40
	print msg
	if WRITE_LOG:
		create_output(msg)

def check_hosts():
	for host in HOST_LIST:
		check_permission(host)

def usage():
    print "Usage: %s [-a]  [-o <output file>]" % sys.argv[0]
    return 0

def getParameters():
	global Get_Host_List_Method
	global file_name
	global WRITE_LOG
	try:
		opts, args = getopt.getopt(sys.argv[1:], "aho:") #if one option needs a parameter then it will be followed by a colon
	except getopt.GetoptError as err:
		print(err)
		usage()
		sys.exit(1)
	for opt, arg in opts:
		if opt == "-h":
			usage()
			sys.exit()
		elif opt == "-a":
			Get_Host_List_Method = False
		elif opt == "-o":
			WRITE_LOG = True
			file_name = arg
			#print "File name is %s, arg is %s" %(file_name, arg)
		else:
			assert False, "unhandled option"
			

# Main
def main():
	global CLUSTER_ADMIN
	global ADMIN_GROUP
	global ELK_HARVEST_LOCATION
	global SHARE_FS
	global HOST_LIST
	global WRITE_LOG
	global TOOL_NAME
	global DEBUG
	global RULE
	global SUCCESS
	global Get_Host_List_Method
	global WRITE_LOG
	global file_name
	getParameters()
	now = time.strftime("%c")
	host_name =  socket.gethostname()
	msg = "*" * 50
	print msg
	if WRITE_LOG:
		create_output(msg)
	msg = "%s on %s test starts" % (now, host_name)
	print msg
	if WRITE_LOG:
		create_output(msg)

	check_env()
	CLUSTER_ADMIN = get_cluster_admin()
	ADMIN_GROUP = get_admin_group(CLUSTER_ADMIN)
	msg = "\nYour cluster admin is %r and admin group is %r." % (CLUSTER_ADMIN, ADMIN_GROUP)
	print msg
	if WRITE_LOG:
		create_output(msg)

	if Get_Host_List_Method:
		HOST_LIST = get_host_list2()
		print "call get_host_list2() Get_Host_List_Method = %r" %Get_Host_List_Method 
	else:
		HOST_LIST = get_host_list1()
		print "call get_host_list1() Get_Host_List_Method = %r" %Get_Host_List_Method 

	msg = "\nThe tool will check ELK harvest location on these hosts:"
	print msg
	if WRITE_LOG:
		create_output(msg)
	for host in HOST_LIST:
		msg = host
		print msg
		if WRITE_LOG:
			create_output(msg)

	ELK_HARVEST_LOCATION = get_harvest_location()
	msg = "\nDriver and app logs will be saved at %s" % ELK_HARVEST_LOCATION
	print msg
	if WRITE_LOG:
		create_output(msg)

	SHARE_FS = shared_fs()
	check_hosts()

	if SUCCESS:
		msg = "\nCongratulations! Your configuration is correct."
		print msg
		if WRITE_LOG:
			create_output(msg)
	else:
		msg = "\nFailed. Please refer to Error messages."
		print msg
		if WRITE_LOG:
			create_output(msg)

	msg = "Done."
	print msg
	if WRITE_LOG:
		create_output(msg)
	msg = "*" * 50
	print msg
	if WRITE_LOG:
		create_output(msg)
	print "\n"
	pass

if __name__ == '__main__':
	main()
